# IOTile Core
A python package for interacting with IOTile based devices.

## Installation

```
pip install iotile-core
```

## Copyright and license
This code is adapted from code and documentation copyright 2015 WellDone
International as pymomo. The IOTile library is released under the
[LGPLv3](https://www.gnu.org/licenses/lgpl.html) Open Source license.  See the
LICENSE file.
